<?php
    require_once( "../sl_root.php" );
    require_once( "core/streamline_init.php" );
    require_once( "core/streamline_functions.php" );


    // Since we use the .htaccess to direct all errors to this page,
    // we should reset the response to return code 200 in case it was
    // set to 404 for a file that doesn't exist.
    header('HTTP/1.1 200\r\n');

    // Get the URI and set these variable so other parts of the app
    // can see what we are trying to access.
    $uri = stripslashes( $_SERVER['REQUEST_URI'] );
    $_SESSION[SL_CURRENT_URI] = $uri;
    $_SESSION[SL_BROWSER_URI] = $uri;
            
    require_once( "core/auth/cookie_login.php" );
    
    if ( $sl_access_controler->requireLoginForBrowsing() )
    {
        require_once( "core/auth/php_login.php" );
    }

    if ( !$sl_access_controler->getBrowseAccess() )
    {
        $msr = $sl_config->getMediaServerRoot();
        $ad_path = joinURLPath( $msr, "browse/access_denied.php" );
        header( "Location: $ad_path" );
        echo "\n";
        die();
    }
    
    require_once( "core/browser/SLBrowser.php" );
    require_once( "core/browser/SLDirExplorer.php" );
    require_once( "core/streamline_functions.php" );
    require_once( "core/theme/SLPageInfo.php" );
    require_once( "core/db/db_init.php" );
    
    
    // Figure out what folder we are trying to browse.
    if ( $sl_config->getMaskURLs() )
    {
        $len = strlen( $uri );
        
        $index_php = "index.php";
        $ilen = strlen( $index_php );
        
        if ( substr( $uri, 0 - $ilen ) == $index_php )
        {
            $uri = substr( $uri, 0, $len - $ilen );
            $len = strlen( $uri );
        }
        else if ( $uri{$len - 1} != '/' )
        {
            header( "Location: ".$uri."/" );
        }
        
        $browse_root = joinURLPath( $sl_config->getMediaServerRoot(), "browse" );
        
        $rootlen = strlen( $browse_root );
        $index = strpos( $uri, $browse_root );
        $dir = substr( $uri, $index + $rootlen , $len - ($index + $rootlen ) );
        $dir = urldecode( $dir );
    }
    else
    {
        $dir = stripslashes( urldecode( isset( $_REQUEST['dir'] )?$_REQUEST['dir']:"/" ) );
    }

    $dir = $sl_platform->normalizePath( $dir );


    $sl_user = null;
    
    if ( isset( $_SESSION[SL_AUTH_USER] ) )
    {
        $auth_user = $_SESSION[SL_AUTH_USER];
        
        require( "core/db/tables/SLUserTable.php" );
        $sl_user_table = new SLUserTable( $db );
        $sl_user = $sl_user_table->getUserById( $auth_user->getUID() );
        $_user_name = $sl_user->getUserName();
    }
    else
    {
        $_user_name = "Unknown";
    }
    
    $sl_dir_explorer = &new SLDirExplorer( $dir, $sl_config, $sl_media_info_cache );
    $sl_browser = &new SLBrowser( $sl_dir_explorer, $sl_config, $sl_access_controler );
    
    if ( !$sl_dir_explorer->isDirectoryBrowseable() )
    {
        $sl_error_msg = "The resource '".rawurldecode($dir)."' does not exist.";
        $sl_logger->logError( $sl_error_msg, $_user_name ); 
        echo $sl_error_msg;
    }
    else
    {
        $sl_logger->logBrowseRequest( $dir, $_user_name ); 
        require_once( "core/stats/SLDailyStatsEngine.php" );
        $sl_stats_engine = &new SLDailyStatsEngine( $db );
        $sl_stats_engine->logBrowse();
        $sl_dir_explorer->traverseDirectory();
    
        $layout_file = $sl_cur_theme->getPath()."/browse/layout.php";

        if ( !is_file( $layout_file ) )
        {
            echo "Streamline cannot browse the media library because no valid theme was found.";
            die();
        }
        else
        {

            $sl_page_info = &new SLPageInfo( SL_BROWSE_PAGE, "Browse" );
            require_once( "core/theme/includes/browse_header.php" );
            require_once( $layout_file );
            require_once( "core/theme/includes/browse_footer.php" );
        }
    }
?>
