<?
require_once( "core/SLConfiguration.php" );
require_once( "core/streamline_functions.php" );

if ( !defined( "_M3U_GENERATOR" ) ){
      define( "_M3U_GENERATOR", 1 );

    class M3UGenerator
    {
    
        var $media_root;
        var $web_server_root;
        var $media_server_root;
        var $m3u;
        var $base_url;
        var $base_proto;
        var $stream_format;
        var $id3_cache;
        var $p_stream;
        var $mask_urls;
        
        function M3UGenerator( &$sl_config, &$sl_media_info_cache )
        {
            $this->media_root = $sl_config->getMediaRoot();
            $this->web_server_root = $sl_config->getWebServerRoot();
            $this->media_server_root = $sl_config->getMediaServerRoot();
            $this->mask_urls = $sl_config->getMaskURLs();

            if ( $this->mask_urls )
            {
                $stream_root = joinURLPath( $this->media_server_root, "stream" );
            }
            else
            {
                $stream_root = joinURLPath( $this->media_server_root, "stream/index.php?media=" );
            }
            
            $this->base_proto = substr( $this->web_server_root, 0, strpos( $this->web_server_root, "://" ) + 3 ); 
            $wsr = substr( $this->web_server_root, strlen( $this->base_proto ), 
                strlen( $this->web_server_root ) - strlen( $this->base_proto ) ); 
            $this->base_url = joinURLPath( $wsr, $stream_root );
            
            $this->stream_format = $sl_config->getStreamFormat();
            $this->id3_cache = $sl_media_info_cache;
            $this->p_stream = $sl_config->getStreamingRequiresAuth();
        }
        
        function & generateM3U( $loc, $sl_user )
        {
            $this->m3u = "#EXTM3U\n";
            $this->recurse( $loc, $sl_user );
            return $this->m3u;
        }
            
        function & generateM3UFromPlaylist( $playlist, $sl_user )
        {
            $this->m3u = "#EXTM3U\n";
            $items = $playlist->getItems();

            foreach( $items as $item )
            {
                $this->addEntry( $item->getPath(), $sl_user );
            }

            return $this->m3u;
        }
        
        function recurse( $loc, $sl_user )
        {
            set_time_limit( 20 );
            
            $cur_path = joinFilePath( $this->media_root, $loc ); 
            
            if ( is_dir( $cur_path ) )
            {
                $handle=opendir( $cur_path );

                if ( $cur_path{ strlen( $cur_path ) - 1 } != '/' )
                {
                    $cur_path = $cur_path."/";
                }
        
                $files = array();
                $dirs = array();
        
                /* This is the correct way to loop over the directory. */
                while (false !== ( $file = readdir($handle) ) ) 
                {
                    
                    if( $file == "." || $file == ".." )
                    {
                        continue;
                    }
            
                    $path = joinFilePath( $cur_path, $file );
                    
                    if ( is_dir( $path  ) )
                    {
                        array_push( $dirs, $file );
                    }
                    else if ( is_file( $path ) )
                    {
                        array_push( $files, $file );
                    }
                }

                sort( $files );
                sort( $dirs );

                $all = $dirs + $files;
                $c = count( $all );
                

                for ( $i = 0; $i < $c; $i++ )
                {
                    $entry = $all[$i];

                    if ( is_file( joinFilePath( $cur_path, $entry ) ) )
                    {
                        $tmp = explode( ".", $entry );
                        $ext = array_pop( $tmp );
                        $ext = strtolower( $ext );
                       
                        global $sl_media_types;
                        
                        if ( array_key_exists( $ext, $sl_media_types ) )
                        {
                            array_push( $files, $file );
                        }
                    }

                    $this->recurse( joinFilePath( $loc, $entry ), $sl_user );
                }
            }
            else if ( is_file( $cur_path ) )
            {

                $tmp = explode( ".", $cur_path );
                $ext = array_pop( $tmp );
                $ext = strtolower( $ext );
               
                global $sl_media_types;
                
                if ( array_key_exists( $ext, $sl_media_types ) )
                {
                    $this->addEntry( $loc, $sl_user );
                }
            }
        }

        function addEntry( $loc, $sl_user )
        {
            $temp = explode( "/", $loc );
            
            $c = count( $temp );
            for( $i = 0; $i < $c; $i++ )
            {
                $temp[$i] = rawurlencode( $temp[$i] );
            }

            $url = implode( "/", $temp );
            
            set_time_limit ( 10 );
            $m_info = $this->id3_cache->getMediaInfo( $loc );
            $filename = rawurldecode( basename( $loc ) );
            $title = formatID3String( $m_info, $this->stream_format, $filename );
            $this->m3u .= "#EXTINF:".intval( $m_info->getSeconds() ).",".$title."\n";
            $base = $this->base_url;
            if ( $this->p_stream && isset( $sl_user ) && $sl_user->getXMMSCompatibility() )
            {
                $base =  $sl_user->getUserName().":".$_SESSION[SL_AUTH_USER]->getClearPassword()."@".$base;
            }
           
            // Get rid of the web path separators that we would be seeing normally.
            if ( !$this->mask_urls )
            {
                $url = str_replace( "/", "%2F", $url );
            }
            
            $this->m3u .= joinURLPath( $this->base_proto.$base, $url )."\n";
        }
        
    }
}
?>
