<?
require_once( "core/net/SLInetAddress.php" );
require_once( "core/db/tables/SLHACTable.php" );
require_once( "core/db/tables/SLAACTable.php" );
require_once( "core/db/tables/SLUserTable.php" );
require_once( "core/access/sl_agent_patterns.php" );

if ( !defined( "_SL_ACCESS_CONTROLER" ) ){
      define( "_SL_ACCESS_CONTROLER", 1 );

    
    class SLAccessControler
    {
        var $addr;
        var $agent;

        var $browse_access;
        var $stream_access;
        var $download_access;

        var $browse_deny_reason;
        var $stream_deny_reason;
        var $download_deny_reason;

        var $browseAuthRequired;
        var $streamAuthRequired;
        var $downloadAuthRequired;
        
        var $admin_access;
        
        var $userid;
        
        function SLAccessControler( $db, $sl_config )
        {
            $this->addr = new SLInetAddress( $_SERVER['REMOTE_ADDR'] );
            $this->agent = $_SERVER['HTTP_USER_AGENT'];

            $this->evaluate( $db, $sl_config );
        }

        function setUserId( $userid )
        {
            $this->userid = $userid;
        }

        function requireLoginForBrowsing()
        {
            return $this->browseAuthRequired;
        }

        function requireLoginForStreaming()
        {
            return $this->streamAuthRequired;
        }

        function requireLoginForDownloading()
        {
            return $this->dowanloadAuthRequired;
        }

        function evaluate( $db, $sl_config )
        {
            $this->browse_access = true;
            $this->stream_access = true;
            $this->download_access = true;
            
            $this->browse_deny_reason = "";
            $this->stream_deny_reason = "";
            $this->download_deny_reason = "";
            
            $this->browseAuthRequired = $sl_config->getBrowsingRequiresAuth();
            $this->streamAuthRequired = $sl_config->getStreamingRequiresAuth();
            $this->dowanloadAuthRequired = $sl_config->getDownloadingRequiresAuth();

            $this->evaluateHAC( $db, $sl_config );
            $this->evaluateAAC( $db, $sl_config );
            $this->evaluateUserAccess( $db );
        }
        
        function evaluateUserAccess( $db )
        {
            $user = null;

            if ( isset( $this->userid ) )
            {
                $user_table = new SLUserTable( $db );
                $user = $user_table->getUserById( $this->userid );
            }
            
            if ( $this->browse_access && $this->browseAuthRequired )
            {
                if ( !isset( $user ) )
                {
                    $this->browse_access = false;
                    $this->browse_deny_reason = "You must be logged in to browse.";
                }
                else
                {
                    $this->browse_access = $user->getBrowse();
                    
                    if ( !$this->browse_access )
                    {
                        $this->browse_deny_reason = "Your user account does not have access to browse.";
                    }
                }
            }
                       
            if ( $this->stream_access && $this->streamAuthRequired )
            {
                if ( !isset( $user ) )
                {
                    $this->stream_access = false;
                    $this->stream_deny_reason = "You must be logged in to stream.";
                }
                else
                {
                    $this->stream_access = $user->getStream();
                    
                    if ( !$this->stream_access )
                    {
                        $this->stream_deny_reason = "Your user account does not have access to stream.";
                    }
                }
            } 

            if ( $this->download_access && $this->dowanloadAuthRequired )
            {
                if ( !isset( $user ) )
                {
                    $this->download_access = false;
                    $this->download_deny_reason = "You must be logged in to download.";
                }
                else
                {
                    $this->download_access = $user->getDownload();
                    
                    if ( !$this->download_access )
                    {
                        $this->download_deny_reason = "Your user account does not have access to download.";
                    }
                }
            } 
            
            if ( !isset( $user ) )
            {
                $this->admin_access = false;
            }
            else
            {
                $this->admin_access = $user->getAdminFlag();
            }
        }


        function evaluateAAC( $db, $sl_config )
        {
            $aac_table = new SLAACTable( $db );
            
            if ( $this->browse_access && $sl_config->getBrowseAACEnabled() )
            {
                $this->browse_access = $this->evaluateAACForService( _SL_AAC_BROWSE, $sl_config->getBrowseAACMode(), $aac_table );
                
                if ( !$this->browse_access )
                {
                    $this->browse_deny_reason = "Your User Agent does not have access to browse.";
                }
            }
            
            if ( $this->stream_access && $sl_config->getStreamAACEnabled() )
            {
                $this->stream_access = $this->evaluateAACForService( _SL_AAC_STREAM, $sl_config->getStreamAACMode(), $aac_table );
                
                if ( !$this->stream_access )
                {
                    $this->stream_deny_reason = "Your User Agent does not have access to browse.";
                }
            }
            
            if ( $this->download_access && $sl_config->getDownloadAACEnabled() )
            {
                $this->download_access = $this->evaluateAACForService( _SL_AAC_DOWNLOAD, $sl_config->getDownloadAACMode(), $aac_table );
                
                if ( !$this->download_access )
                {
                    $this->download_deny_reason = "Your User Agent does not have access to browse.";
                }
            }
        }

        function evaluateAACForService( $service, $mode, $aac_table )
        {
            $rule = ($mode == "deny" || $mode == 1)?_SL_AAC_DENY:_SL_AAC_ALLOW;
            
            $entries = $aac_table->getEntriesByServiceAndRule( $service, $rule );

            $found = false;

            foreach ( $entries as $entry )
            {
                $ptype = $entry->getPatternType(); 
                $pattern = $entry->getPattern(); 
                if( $ptype == _SL_AAC_IS )
                {
                    $found = $pattern == $this->agent;
                    if ( $found )
                    {
                        break;
                    }
                }
                else if ( $ptype == _SL_AAC_CONTAINS )
                {
                    $found = strpos( $pattern, $this->agent );
                    if ( $found )
                    {
                        break;
                    }
                }
                else if ( $ptype == _SL_AAC_REGEX )
                {
                    $found = @preg_match( $pattern, $this->agent );
                    if ( $found )
                    {
                        break;
                    }
                }
                else if ( $ptype == _SL_AAC_COMMON )
                {
                    global $sl_agent_patterns;
                    $pattern = $sl_agent_patterns[$pattern];
                    $found = @preg_match( $pattern, $this->agent ) != false;
                    if ( $found )
                    {
                        break;
                    }
                }
            }

            return ($rule == _SL_AAC_ALLOW && $found) || ( $rule == _SL_AAC_DENY && !$found );
        }

        function evaluateHAC( $db, $sl_config )
        {
            $hac_table = new SLHACTable( $db );
            
            if( $sl_config->getGlobalHACEnabled() )
            {
                $global_access = $this->evaluateHACForService( "global", $sl_config->getGlobalHACDefault(), $hac_table );
            }
            else
            {
                $global_access = true;
            }


            // At this point we have a global rule to fall back on if we don't 
            // find anything specific.  Now we look at each service
            
            if ( $this->browse_access )
            {
                if( $sl_config->getBrowseHACEnabled() )
                {
                    $this->browse_access = $this->evaluateHACForService( "browse", $sl_config->getBrowseHACDefault(), $hac_table );
                }
                else
                {
                    $this->browse_access = $global_access;
                }
                
                if ( !$this->browse_access )
                {
                    $this->browse_deny_reason = "Your IP Address does not have access to browse.";
                }
            }

            
            if ( $this->stream_access )
            {
                if( $sl_config->getStreamHACEnabled() )
                {
                    $this->stream_access = $this->evaluateHACForService( "stream", $sl_config->getStreamHACDefault(), $hac_table );
                }
                else
                {
                    $this->stream_access = $global_access;
                }
                
                if ( !$this->stream_access )
                {
                    $this->stream_deny_reason = "Your IP Address does not have access to stream.";
                }
            }
            
            
            if ( $this->download_access )
            {
                if( $sl_config->getDownloadHACEnabled() )
                {
                    $this->download_access = $this->evaluateHACForService( "download", $sl_config->getDownloadHACDefault(), $hac_table );
                }
                else
                {
                    $this->download_access = $global_access;
                }
                
                if ( !$this->download_access )
                {
                    $this->download_deny_reason = "Your IP Address does not have access to download.";
                }
            }
        }

        function evaluateHACForService( $service, $default, $hac_table )
        {
            $access = false;
            
            $allow = $this->hacEntryForServiceAndRuleExists( $service, "allow", $hac_table );
            $deny = $this->hacEntryForServiceAndRuleExists( $service, "deny", $hac_table );
             
            if ( !$allow && !$deny )
            {
                // If we didn't find an entry the the global default is used.
                $access = $default == "allow";
            }
            else if ( $allow && !$deny )
            {
                // We found an allow rule but not a deny rule so access is allowed.
                $access = true;
            }
            else if ( !$allow && $deny )
            {
                // We found an allow rule but not a deny rule so access is allowed.
                $access = false;
            }
            else if ( $allow && $deny )
            {
                // We found both allow and deny rules so we use the default
                // as the one with precedance.
                $access = $default == "allow";
            }

            return $access;
        }

        
        function hacEntryForServiceAndRuleExists( $service, $rule, $hac_table )
        {
            $result = false;
            $host_addr = $this->addr->getDecimalIP(); 

            $entries = $hac_table->getEntriesByServiceAndRule( $service, $rule );
            foreach ( $entries as $entry )
            {
                $low = new SLInetAddress( $entry->getStartIP() );
                $high = new SLInetAddress( $entry->getEndIP() );
                
                if ( $low->getDecimalIP() <=  $host_addr &&
                     $high->getDecimalIP() >= $host_addr )
                {
                    $result = true;
                    break;
                }
            }

            return $result;
        }

        function getAdminAccess()
        {
            return $this->admin_access;
        }

        function getBrowseAccess()
        {
            return $this->browse_access;
        }

        function getBrowseDenyReason()
        {
            return $this->browse_deny_reason;
        }

        function getStreamAccess()
        {
            return $this->stream_access;
        }

        function getStreamDenyReason()
        {
            return $this->stream_deny_reason;
        }


        function getDownloadAccess()
        {
            return $this->download_access;
        }

        function getDownloadDenyReason()
        {
            return $this->download_deny_reason;
        }

    }
}
?>
