<?php
require_once( "core/streamline_functions.php" );
require_once( "core/browser/SLMediaTableGen.php" );
require_once( "core/browser/SLDirTableGen.php" );
require_once( "core/ui/nav/SLLink.php" );

if ( !defined( "_SL_BROWSER" ) ){
      define( "_SL_BROWSER", 1 );



    class SLBrowser
    {
        var $media_server_root;
        var $browse_root;
        var $path;
        var $parent_path;
        var $up_path;
        var $theme_path;
        var $web_server_root;
        var $browser_columns;
        var $sort_order;
        var $show_play;
        var $dir_explorer;
        var $access_controler;
        var $mask_urls;
        var $web_path;


        function SLBrowser( &$dir_explorer, &$sl_config, &$access_controler )
        {
            $this->media_server_root = $sl_config->getMediaServerRoot();
            $this->browse_root = joinURLPath( $this->media_server_root, "browse");

            global $sl_platform;

            $this->dir_explorer = &$dir_explorer;
            $dir = $sl_platform->normalizePath( $dir_explorer->getDir() );


            $sep = $sl_platform->getPathSeparator();
            $this->path = explode( $sep, $dir );
            $this->web_path = implode( "/", $this->path );


            $this->access_controler = &$access_controler;


            $this->parent_path = explode( $sep, $dir );
            array_pop( $this->parent_path );
            array_pop( $this->parent_path );
            $this->up_path = join( "/", $this->parent_path );
            $this->up_path = $this->up_path."/";

            $this->theme_path = "themes/".$sl_config->getTheme();
            $this->web_server_root = $sl_config->getWebServerRoot();
            $this->browser_columns = $sl_config->getBrowserColumns();
            $this->sort_order = $sl_config->getSortOrder();

            $this->show_play = $access_controler->getStreamAccess();
            $this->mask_urls = $sl_config->getMAskURLs();
        }



        function getBreadCrums()
        {
            $result = array();
            $result[] = new SLLink( $this->browse_root, "Home", "Home", "sl_bread_crum_link" );

            $link_path = "";

            foreach( $this->path as $cur_path )
            {
                if( $cur_path != "" )
                {
                    if ( $link_path == "" )
                    {
                        $link_path = $cur_path;
                    }
                    else
                    {
                        $link_path = joinURLPath( $link_path, $cur_path );
                    }

                    $href = htmlspecialchars( $link_path );

                    if ( $this->mask_urls )
                    {
                        $href = joinURLPath( $this->browse_root, $href );
                    }
                    else
                    {
                        $href = joinURLPath( joinURLPath( $this->browse_root, "/index.php?dir=" ), $href );
                    }


                    $result[] = new SLLink(
                        $href,
                        htmlspecialchars( $cur_path ),
                        htmlspecialchars( $cur_path ),
                        "sl_bread_crum_link" );
                }
            }

            return $result;
        }

        function showParentLink()
        {

            return $this->web_path != "/" && $this->web_path != "";
        }

        function getParentLink()
        {
            if ( $this->mask_urls )
            {
                $href = joinURLPath( $this->browse_root, htmlspecialchars( $this->up_path ) );
            }
            else
            {
                $href = joinURLPath( joinURLPath( $this->browse_root, "index?dir="), htmlspecialchars( $this->up_path ) );
            }

            return new SLLink(
                $href,
                "Parent Directory",
                "Parent Directory",
                "sl_bread_crum_link" );
        }

        function showPlayLink()
        {
            return $this->show_play;
        }

        function getPlayLink()
        {
            if ( $this->mask_urls )
            {
                $href = joinURLPath( htmlspecialchars( joinURLPath( joinURLPath( $this->media_server_root, "m3u" ), $this->web_path ) ), "play_all.m3u" );
            }
            else
            {
                $href = joinURLPath( htmlspecialchars( joinURLPath( joinURLPath( $this->media_server_root, "m3u/index.php?media=" ), $this->web_path ) ), "play_all.m3u" );
            }

            return new SLLink(
                $href,
                "Play",
                "Play",
                "sl_bread_crum_link" );
        }

        function hasFiles()
        {
            return $this->dir_explorer->getNumFiles() > 0;
        }

        function outputFilesBrowser()
        {
            $table_gen = new SLMediaTableGen(
                $this->dir_explorer->getFiles(),
                $this->browser_columns,
                $this->media_server_root,
                $this->access_controler );

            $table_gen->generateTable( "" );
        }

        function hasDirs()
        {
            return $this->dir_explorer->getNumDirs() > 0;
        }

        function outputDirsBrowser()
        {
            $table_gen = new SLDirTableGen(
                $this->dir_explorer->getDir(),
                $this->dir_explorer->getDirs(),
                $this->media_server_root,
                $this->access_controler );

            $table_gen->generateTable( "" );
        }
    }
}
?>
