<?php

require_once( "core/db/objects/SLMediaStats.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_MEDIA_STATS_TABLE" ) ){
      define( "_SL_MEDIA_STATS_TABLE", 1 );

    class SLMediaStatsTable 
    {
        var $db;

        function SLMediaStatsTable( $db )
        {
            $this->db = &$db;
        }

        
        function createMediaStats( $path  )
        {
            $template = "INSERT INTO stats_media ( path,  streams, downloads ) VALUES ( ?, 0, 0 )";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $path );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        function deleteMediaStats( $path )
        {
            $template = "DELETE FROM stats_media WHERE path = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $path );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
        

        function getStatsForMedia( $path )
        {
            $result = null;
            
            $template = "SELECT path FROM stats_media WHERE path = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $path );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    $result = new SLMediaStats( $this->db, $rows[0]['path'] );
                }
            }

            return $result;
        }


        function statsExistForMedia( $path )
        {
            $result = false;
            
            $template = "SELECT path FROM stats_media WHERE path = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $path );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                $result = is_array( $rows ) && count( $rows ) > 0;
            }
            
            return $result; 
        }
            
               
        function getTopRankedMediaByDownloads( $num )
        {
            return $this->getHighestRankedMedia( "downloads", $num );
        } 
        
        function getTopRankedMediaByStreams( $num )
        {
            return $this->getHighestRankedMedia( "streams", $num );
        }
        
        function getHighestRankedMedia( $stat, $num, $offset = 0 )
        {
            $result = false;
            
            $template = "SELECT * FROM stats_media WHERE $stat > 0 ORDER BY $stat DESC LIMIT ? OFFSET ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $num );
            $sql->setValue( 1, $offset );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLMediaStats( $this->db, $row['path'] ) );
                }    
            }
            
            return $result;
        }

        function getNumberOfRankedMedia( $stat )
        {
            $result = 0;

            $qr = $this->db->query( "SELECT COUNT(path) FROM stats_media WHERE $stat > 0" );
            if ( $qr )
            {
                $last = $this->db->getLastResult();
                $result = array_pop( $last[0] );
            }
            else
            {
                $result = -1;
            }
            
            return $result;           
        }
    }
}
?>
