<?php

require_once( "core/db/objects/SLMedia.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_MEDIA_TABLE" ) ){
      define( "_SL_MEDIA_TABLE", 1 );

    class SLMediaTable
    {
        var $db;

        function SLMediaTable( $db )
        {
            $this->db = $db;
        }

        
        function createMedia( $path, $title, $artist, $album, $genre, $year, $filename, $modtime )
        {
            
            $template = "INSERT INTO media (path, title, artist, album, genre, year, filename, modtime) VALUES ( ?, ?, ?, ?, ?, ?, ?, ? )";

            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $path );
            $sql->setValue( 1, $title );
            $sql->setValue( 2, $artist );
            $sql->setValue( 3, $album );
            $sql->setValue( 4, $genre );
            $sql->setValue( 5, $year );
            $sql->setValue( 6, $filename );
            $sql->setValue( 7, $modtime );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        function deleteMedia( $path )
        {
            $sql = SQLStatement::createStatement( "DELETE FROM media where path = ?" );
            $sql->setValue( 0, $path );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
        

        function deleteAllMedia()
        {
            $this->db->query( "DELETE FROM media where 1" );
        }
        
        function getMediaByPath( $path )
        {
            $result = null;

            $sql = SQLStatement::createStatement( "SELECT path FROM media WHERE path = ?" );
            $sql->setValue( 0, $path );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    $result = new SLMedia( $this->db, $rows[0]['path'] );
                }
            }

            return $result;
        }

        function searchMediaForRange( $where_clause, $num_per_page, $page )
        {
            $result = null;
            $start = $num_per_page * $page;
            
            $template = "SELECT path FROM media ".$where_clause." LIMIT ? OFFSET ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $num_per_page );
            $sql->setValue( 1, $start );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                foreach( $rows as $row )
                {
                    array_push( $result, new SLMedia( $this->db, $row['path'] ) );
                }
            }

            return $result;
        }
        
        
        function getNumSearchResults( $where_clause )
        {
            $result = 0;
            $sql = "SELECT COUNT(path) FROM media ".$where_clause ;
            $qr = $this->db->query( $sql  );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                $result = array_pop( $rows[0] );
            }
            

            return $result;
        }

        
        function getAllMediaInRange( $num_per_page, $page )
        {
            $start = $num_per_page * $page;

            $template = "SELECT path FROM media LIMIT ? OFFSET ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $num_per_page );
            $sql->setValue( 1, $start );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    foreach( $rows as $row )
                    {
                        array_push( $result, new SLMedia( $this->db, $row['path'] ) );
                    }
                }    
            }
            
            return $result;
        }
    }
}
?>
