<?php

require_once( "core/db/objects/SLUser.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_USER_TABLE" ) ){
      define( "_SL_USER_TABLE", 1 );

    class SLUserTable
    {
        var $db;

        function SLUserTable( $db )
        {
            $this->db = $db;
        }

        
        function createUser( $uname, $fname, $lname, $password, $email, $admin, $browse, $stream, $download  )
        {
            $template = "INSERT INTO users ".
                "( uname, fname, lname, password, email, admin, browse, stream, download ) ".
                "VALUES ( ?, ?, ?, ?, ?, ?, ?, ?, ? )";
                
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uname );
            $sql->setValue( 1, $fname );
            $sql->setValue( 2, $lname );
            $sql->setValue( 3, $password );
            $sql->setValue( 4, $email );
            $sql->setValue( 5, $admin?1:0 );
            $sql->setValue( 6, $browse?1:0 );
            $sql->setValue( 7, $stream?1:0 );
            $sql->setValue( 8, $download?1:0 );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        function deleteUser( $userid )
        {
            // Delete this user's playlists
            require_once( "core/db/tables/SLPlayListTable.php" );
            $playlist_table = &new SLPlayListTable( $this->db );
            $lists = $playlist_table->getPlayListsByUserID( $userid );

            foreach( $lists as $list )
            {
                $playlist_table->deletePlayList( $list->getListId() );
            }          
           
           
            // Delete this user's last login entry.
            require_once( "core/db/tables/SLLastLoginTable.php" );
            $ll_table = &new SLLastLoginTable( $this->db );
            $ll_table->deleteLastLoginForUID( $userid );
            

            // Delete this user's stats.
            require_once( "core/db/tables/SLUserStatsTable.php" );
            $user_stats_table = &new SLUserStatsTable( $this->db );
            $user_stats_table->deleteUserStatsForUID( $userid );
            

            // Finally get rid of the user.
            $template = "DELETE FROM users WHERE uid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $userid );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
        

        function getUserByName( $uname )
        {
            $result = null;
            
            $template = "SELECT uid FROM users WHERE uname = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uname );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    $result = new SLUser( $this->db, $rows[0]['uid'] );
                }
            }

            return $result;
        }


        function getUserById( $userid )
        {
            $result = null;
            
            $template = "SELECT uid FROM users WHERE uid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $userid );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    $result = new SLUser( $this->db, $rows[0]['uid'] );
                }
            }

            return $result;
        }

        function userExists( $uname )
        {
            $result = false;
            
            $template = "SELECT uid FROM users WHERE uname = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uname );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                $result = is_array( $qr ) && count( $qr ) > 0;
            }
            
            return $result; 
        }
            
        
        function getAllUsers()
        {
            $qr = $this->db->query( "SELECT uid FROM users" );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLUser( $this->db, $row['uid'] ) );
                }    
            }
            
            return $result;
        }

        function getUsersByPrivelege( $priv, $state )
        {
            $template = "SELECT uid FROM users WHERE $priv = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $state );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLUser( $this->db, $row['uid'] ) );
                }    
            }
            
            return $result;
        }
        
        function setUsersPrivilege( $service, $users )
        {
            $where_clause = "(";
      
            foreach( $users as $user )
            {
                if ( $where_clause != "(" )
                {
                    $where_clause .= " OR ";
                }
                
                $where_clause .= "uname = ?";
            }

            $where_clause .= ")";

            $where = SQLStatement::createStatement( $where_clause );
            
            $count = count( $users );
            
            $i = 0;
            foreach ( $users as $user )
            {
                $where->setValue( $i, $user );
                $i++;
            }

            $where_sql = $where->toSQL();
            
            $sql1 = "UPDATE users set $service = 1 WHERE $where_sql";
            $sql2 = "UPDATE users set $service = 0 WHERE NOT $where_sql";

            $result = $this->db->query( $sql1 );
            $result = $this->db->query( $sql2 );

            return $result;
        }
    }
}
?>
