<?
if ( !defined( "_SL_CIDR_RANGE" ) ){
      define( "_SL_CIDR_RANGE", 1 );

    class SLCIDRRange
    {
        var $notation;
        var $low_quad;
        var $high_quad;
        var $error;
        
        function SLCIDRRange( $notation )
        {
            $this->notation = $notation;
        }

        function parse()
        {
            list( $ip, $mask ) = split( "/", $this->notation );

            if ( preg_match("/\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/",$ip) != 1 ) 
            {
                $this->error = "The supplied IP address $ip, does not follow the dotted quad form.";
                return false;
            }

            $quad = explode( ".", $ip );

            foreach ( $quad as $val )
            {
                if ( $val < 0 || $val > 255 ) 
                {
                    $this->error = "Each section of the dotted quad IP address must be between 0 and 255.";
                    return false;
                }
            }

            
            if ( $mask > 32 || $mask < 0 )
            {
                $this->error = "The network prefix mask must be between 0 and 32 inclusive.";
                return false;
            
            }
            
            //we'll only deal with class C ranges /24 to /32 for now.
            if ( $mask == 32 || $mask == 0 ) 
            {
                // There is no range.
                $start_ip = $ip;
                $end_ip = $ip;
            }

            if ($mask == 31) 
            {
                $this->error = "There are only 2 ip addresses in this range and neither of them ".
                               "and neither of them are usable";
                return false;
            }
            
            
            $bin0 = str_pad( decbin( $quad[0] ), 8, "0", STR_PAD_LEFT );
            $bin1 = str_pad( decbin( $quad[1] ), 8, "0", STR_PAD_LEFT );
            $bin2 = str_pad( decbin( $quad[2] ), 8, "0", STR_PAD_LEFT );
            $bin3 = str_pad( decbin( $quad[3] ), 8, "0", STR_PAD_LEFT );

            $bin_ip = $bin0.$bin1.$bin2.$bin3;
            $bin_low_mask = str_pad( "", $mask, "1", STR_PAD_LEFT ); 
            $bin_low_mask = str_pad( $bin_low_mask, 32, "0", STR_PAD_RIGHT );
            
            $bin_high_mask = str_pad( "", $mask, "0", STR_PAD_LEFT ); 
            $bin_high_mask = str_pad( $bin_high_mask, 32, "1", STR_PAD_RIGHT );  
            $dec_ip = bindec( $bin_ip );
            $dec_low_mask = bindec( $bin_low_mask ); 
            $dec_high_mask = bindec( $bin_high_mask ); 
            
            $dec_low = $dec_ip & $dec_low_mask;
            $dec_high = $dec_ip | $dec_high_mask;
            
            $bin_low = decbin( $dec_low );
            $bin_high = decbin( $dec_high );

            $low_quad = array();
            $low_quad[0] = bindec( substr( $bin_low, 0, 8 ) );
            $low_quad[1] = bindec( substr( $bin_low, 8, 8 ) );
            $low_quad[2] = bindec( substr( $bin_low, 16, 8 ) );
            $low_quad[3] = bindec( substr( $bin_low, 24, 8 ) );
            $this->low_quad = $low_quad;
            
            $high_quad = array();
            $high_quad[0] = bindec( substr( $bin_high, 0, 8 ) );
            $high_quad[1] = bindec( substr( $bin_high, 8, 8 ) );
            $high_quad[2] = bindec( substr( $bin_high, 16, 8 ) );
            $high_quad[3] = bindec( substr( $bin_high, 24, 8 ) );
            $this->high_quad = $high_quad;

            return true;
        }

        function getError()
        {
            return $this->error;
        }

        function getLowQuad()
        {
            return $this->low_quad;
        }
        
        function getLowIPString()
        {
            return implode( ".", $this->low_quad );
        }

        function getHighQuad()
        {
            return $this->high_quad;
        }
        
        function getHighIPString()
        {
            return implode( ".", $this->high_quad );
        }
    }
}
?>
