<?
require_once( "core/db/tables/SLMediaTable.php" );
require_once( "core/search/SLSearchRequest.php" );
require_once( "core/streamline_functions.php" );
require_once( "core/browser/SLMediaInfo.php" );

if ( !defined( "_SL_SEARCH_ENGINE" ) ){
      define( "_SL_SEARCH_ENGINE", 1 );
    
    class SLSearchEngine
    {
        var $media_table;
        var $results;
        var $music_path;
        var $dl_path;
        var $media_root;
        var $sl_media_info_cache;
        var $media_server_root;
        var $mask_urls;
        
        function SLSearchEngine( $db, &$sl_config, &$sl_media_info_cache )
        {
            $this->media_table = &new SLMediaTable($db);
            $this->results = array(); 
            $this->media_root = $sl_config->getMediaRoot();
            $this->sl_media_info_cache = &$sl_media_info_cache;
            $this->media_server_root = $sl_config->getMediaServerRoot();
            $this->mask_urls = $sl_config->getMaskURLs();
        }

        function performAdvancedSearch( $request, $num_per_page, $page )
        {
            $where_clause = $this->constructSQLWhereClause( $request );
            return $this->search( $where_clause, $num_per_page, $page );
        }

        function performSimpleSearch( $string, $num_per_page, $page )
        {
            $term = addslashes( $string );
			$lstring = strtolower( $string );
            $where_clause = "WHERE LOWER(title) LIKE '%$lstring%' OR LOWER(album) LIKE '%$lstring%' OR LOWER(artist) LIKE '%$lstring%' OR LOWER(filename) LIKE '%$lstring%'";
            return $this->search( $where_clause, $num_per_page, $page );
        }
            
        function & search( $where_clause, $num_per_page, $page )
        {
            $media_array = $this->media_table->searchMediaForRange( $where_clause, $num_per_page, $page );
            
            if ( is_array( $media_array )  && count( $media_array > 0 ) )
            {
                foreach ( $media_array as $media )
                {
                    $path = joinFilePath( $this->media_root, $media->getPath() );

                    // We check to see if this file actually exists on our server.
                    // If not, don't display it.
                    if ( is_file( $path ) )
                    {
                        $info = &$this->sl_media_info_cache->getMediaInfo( $media->getPath() );
                        $web_path = createWebPath( $media->getPath() );
                        array_push( $this->results, new SLMediaInfo( $this->media_server_root, $web_path, $this->mask_urls, $info  ) );
                    }
                }
            }

            return $this->media_table->getNumSearchResults( $where_clause );
        }
        
        function getResults()
        {
            return $this->results; 
        }

        function constructSQLWhereClause( $request )
        {
            $where_clause = "WHERE ";
            $term_added = false;

            if ( $request->getTitleOperand() != "" )
            {
                $where_clause .= $this->getTerm( "title", $request->getTitleOperator(), $request->getTitleOperand(), true );
                $term_added = true;
            }
            
            if ( $request->getArtistOperand() != "" )
            {
                $where_clause .= $this->getTerm( "artist", $request->getArtistOperator(), $request->getArtistOperand(), !$term_added );
                $term_added = true;
            }

            if ( $request->getAlbumOperand() != "" )
            {
                $where_clause .= $this->getTerm( "album", $request->getAlbumOperator(), $request->getAlbumOperand(), !$term_added );
                $term_added = true;
            }
            
            if ( $request->getFileOperand() != "" )
            {
                $where_clause .= $this->getTerm( "filename", $request->getFileOperator(), $request->getFileOperand(), !$term_added );
                $term_added = true;
            }
            
            if ( $request->getYearOperand() != "" )
            {
                $where_clause .= $this->getTerm( "year", $request->getYearOperator(), $request->getYearOperand(), !$term_added );
                $term_added = true;
            }
            
            if ( $request->getGenreOperand() != "" )
            {
                $where_clause .= $this->getTerm( "genre", $request->getGenreOperator(), $request->getGenreOperand(), !$term_added );
                $term_added = true;
            }

            if ( !$term_added )
            {
                $where_clause = "WHERE 0";
            }
            
            return $where_clause;
        }

        function getTerm( $property, $operator, $operand, $first_term = true )
        {
            $term = $first_term?"":"AND ";
            
            switch( $operator )
            {
                case "like":
                    $loperand = strtolower( $operand );
                    $term .= "LOWER(".$property.")"." LIKE '%$loperand%'";
                    break;

                case "equal":
                    $term .= $property." = '$operand'";
                    break;

                case "not equal":
                    $term .= $property." != '$operand'";
                    break;

                case "greaterthan":
                    $term .= $property." > '$operand'";
                    break;

                case "lessthan":
                    $term .= $property." < '$operand'";
                    break;
             }

             return $term;
        }
    }   
}
?>
