<?
require_once( "core/db/tables/SLDailyStatsTable.php" );

if ( !defined( "_SL_DAILY_STATS_ENGINE" ) ){
      define( "_SL_DAILY_STATS_ENGINE", 1 );

    class SLDailyStatsEngine
    {
        var $db;
        var $table;
        var $today;
        var $day_offset;

        function SLDailyStatsEngine( $db )
        {
            $this->db = &$db;
            $this->table = &new SLDailyStatsTable( $this->db );
            $this->today = strtotime( date( "d F Y" ) ); 
            $this->day_offset = 60*60*24; 
        }


        //
        // Stream Functions
        //
        
        function logStream()
        {
            $this->incrementStatForService( "stream" );
        }

        function getTodaysStreams()
        {
            $stat = $this->table->getDailyStats( $this->today );
            return isset( $stat )?$stat->getStreams():0;
        }

        function getPastStreams( $days )
        {
            return $this->getPastStatsForService( "stream", $days );
        }

        function getStreamsForRangeOfTime( $start_time, $end_time )
        {
            return $this->getStatsForServiceOverRange( "stream", $start_time, $end_time);
        }

        
        //
        // Browse Functions
        //
        
        function logBrowse()
        {
            $this->incrementStatForService( "browse" );
        }

        function getTodaysBrowses()
        {
            $stat = $this->table->getDailyStats( $this->today );
            return isset( $stat )?$stat->getBrowses():0;
        }

        function getPastBrowses( $days )
        {
            return $this->getPastStatsForService( "browse", $days );
        }

        function getBrowsesForRangeOfTime( $start_time, $end_time )
        {
            return $this->getStatsForServiceOverRange( "browse", $start_time, $end_time);
        }
        

        //
        // Download Functions
        //
        
        function logDownload()
        {
            $this->incrementStatForService( "download" );
        }

        function getTodaysDownloads()
        {
            $stat = $this->table->getDailyStats( $this->today );
            return isset( $stat )?$stat->getDownloads():0;
        }

        function getPastDownloads( $days )
        {
            return $this->getPastStatsForService( "download", $days );
        }

        function getDownloadsForRangeOfTime( $start_time, $end_time )
        {
            return $this->getStatsForServiceOverRange( "download", $start_time, $end_time);
        }

        
        // Common Helpers
        function getStatsForServiceOverRange( $service, $start_time, $end_time )
        {
            $stats = $this->table->getStatsForRangeOfTime( $start_time, $end_time );
            $result = array();

            $days = ($end_time - $start_time) / $this->day_offset + 1;

            
            // This pads the array with the correct times, and sets them to 
            // zero.  Turns out this is simpler than trying to figure out
            // which ones we got after the fact.
            for ( $i = 0; $i < $days; $i++ )
            {
                $time = $end_time + ( ($i - ($days - 1)) * $this->day_offset );
                
                $result[$time] = 0; 
            }
            
            foreach( $stats as $stat )
            {
                $num = 0;
                switch( $service )
                {
                    case "browse":
                        $num = $stat->getBrowses();
                        break;

                    case "stream":
                        $num = $stat->getStreams();
                        break;
                        
                    case "download":
                        $num = $stat->getDownloads();
                        break;
                }
                
                $result[$stat->getDate()] = $num;
            }

            return $result;
        }


        function getPastStatsForService( $service, $days )
        {
            $days_offset = $this->day_offset*( $days - 1 );
            $start_time = $this->today - $days_offset;
            $end_time = $this->today;
            
            return $this->getStatsForServiceOverRange( $service, $start_time, $end_time);
        }

        function incrementStatForService( $service )
        {
            $stat = null;
            
            if ( !$this->table->statsExistForDay( $this->today ) )
            {
                $stat = $this->table->createDailyStats( $this->today );
            } 
            
            $stat = $this->table->getStatsForDay( $this->today );

            switch( $service )
            {
                case "browse":
                    $stat->incrementBrowses();
                    break;
                
                case "stream":
                    $stat->incrementStreams();
                    break;
                
                case "download":
                    $stat->incrementDownloads();
                    break;
            }

            $stat->store();
        }
    }
}
?>
