<?php
    require_once( "../sl_root.php" );
    require_once( "installer/config_check.php" );
    require_once( "core/SLConfiguration.php" );
    require_once( "core/platform/platform_require.php" );
    
    session_start();
    
    require_once( "core/platform/platform_init.php" );

    $rdbms_install = array( "database_config", "locations", "admin_user", "authentication", "confirm_install" );
    $sqlite_install = array( "locations", "admin_user", "authentication", "confirm_install" ); 
    
    // If the new config object doesn't exitst, lets create it.
    if ( !isset( $_SESSION['SL_NEW_CONFIG'] ) )
    {
        $config = &new SLConfiguration();

        if ( isset( $_SERVER['SERVER_NAME'] ) )
        {
            $config->setWebServerRoot( "http://".$_SERVER['SERVER_NAME'] );
        }
        else
        {
            $config->setWebServerRoot( "http://www.yourdomain.com" );
        }

        if ( isset( $_SERVER['REQUEST_URI'] ) )
        {
            $uri = stripslashes( $_SERVER['REQUEST_URI'] );
            $index = strpos( $uri, "installer/install_handler.php" );
            $root = substr( $uri, 0, $index  );
            $config->setMediaServerRoot( $root );
        }
        else
        {
            $config->setMediaServerRoot( "/streamline/" );
        }

        
        // Set Up Defaults
        $config->setTheme( "default" );
        
        if ( $sl_platform->getName() == 'Windows') 
        {
            $config->setMediaRoot( "C:\\media\\" );
        }
        else
        {
            $config->setMediaRoot( "/var/media/" );
        }
        
        $config->setServerTitle( "Streamline Media Server" );
        $config->setBrowserColumns( array( "title", "album", "artist" ) );
        $config->setStreamFormat( "%t - %n" );
        $config->setSortOrder( array( "TRACK", "TITLE" ) );
        $config->setBrowsingRequiresAuth( true );
        $config->setStreamingRequiresAuth( true );
        $config->setDownloadingRequiresAuth( true );
        $config->setAdminRequiresAuth( true );
        $config->setGlobalHACEnabled( false );
        $config->setBrowseHACEnabled( false );
        $config->setStreamHACEnabled( false );
        $config->setDownloadHACEnabled( false );
        
        $config->setBrowseAACEnabled( false );
        $config->setStreamAACEnabled( false );
        $config->setDownloadAACEnabled( false );

        $config->setLogBrowsing( true );
        $config->setLogStreaming( true );
        $config->setLogDownloading( true );
                
        if ( !isset( $_SESSION['sl_install_db_type'] ) )
        {
            $_SESSION['sl_install_db_type'] = "mysql";
            $_SESSION['sl_install_db_host'] = "localhost";
            $_SESSION['sl_install_db_user'] = "streamline";
            $_SESSION['sl_install_db_pass'] = "password";
            $_SESSION['sl_install_db_name'] = "streamline";
        }

        $_SESSION['SL_NEW_CONFIG'] = &$config;
    }
    else
    {
        $config = &$_SESSION['SL_NEW_CONFIG'];
    }
    
    // Figure out what path we are on for configuration. 
    switch ( $_SESSION['dbms_type'] )
    {
        case "rdbms":
            $sequence = $rdbms_install;
             break;

        case "sqlite":
            $sequence = $sqlite_install;
            break;

        default:
            header( "Location: dbms_type.php" );
            break;
    }
    
    $num_steps = count( $sequence );
    $_SESSION['sl_num_steps'] = $num_steps;
    
    if ( !isset( $_REQUEST['step_name'] ) )
    {
        $_SESSION['sl_cur_step_num'] = 0;
        header( "Location: ".( $sequence[0] ).".php" );
        echo "\n";
    }
    else
    {
        $step_name = $_REQUEST['step_name'];
        $step_num = 0;
        foreach( array_keys( $sequence ) as $key )
        {
            if ( $sequence[$key] == $step_name )
            {
                $step_num = $key;
                break;
            }
        }
    }

    
    if ( $step_num >= 0 && $step_num < count( $sequence ) )
    {
        switch ( $sequence[$step_num] )
        {
            
            case "database_config":
                $_SESSION['sl_install_db_type'] = $_REQUEST['db_type'];
                $_SESSION['sl_install_db_host'] = $_REQUEST['db_host'];
                $_SESSION['sl_install_db_user'] = $_REQUEST['db_user'];
                $_SESSION['sl_install_db_pass'] = $_REQUEST['db_pass'];
                $_SESSION['sl_install_db_name'] = $_REQUEST['db_name'];
                break;
            
            case "locations":
                $config->setWebServerRoot( $_REQUEST['WebServerRoot'] );
                $config->setMediaServerRoot( $_REQUEST['MediaServerRoot'] );
                $config->setMediaRoot( $sl_platform->normalizePath( $_REQUEST['MediaRoot'] ) );
                break;

            case "presentation":
                $config->setBrowseFormat( $_REQUEST['BrowseFormat'] );
                $config->setStreamFormat( $_REQUEST['StreamFormat'] );
                $config->setSortOrder( $_REQUEST['SortOrder'] );
                $config->setTheme( $_REQUEST['Theme'] );
                break;

            case "admin_user":
                $_SESSION['SL_ADMIN_USER'] = stripslashes( $_REQUEST['admin_user'] );
                $_SESSION['SL_ADMIN_FNAME'] = stripslashes( $_REQUEST['admin_fname'] );
                $_SESSION['SL_ADMIN_LNAME'] = stripslashes( $_REQUEST['admin_lname'] );
                $_SESSION['SL_ADMIN_EMAIL'] = stripslashes( $_REQUEST['admin_email'] );
                $_SESSION['SL_ADMIN_PASS'] = stripslashes( $_REQUEST['admin_pass'] );
                break;

            case "authentication":
                $config->setBrowsingRequiresAuth( (strtoupper( $_REQUEST['ProtectBrowsing'] ) == "YES")?true:false );
                $config->setStreamingRequiresAuth( (strtoupper( $_REQUEST['ProtectStreaming'] ) == "YES")?true:false );
                $config->setDownloadingRequiresAuth( (strtoupper( $_REQUEST['ProtectDownloading'] ) == "YES")?true:false );
                break;

            default:
                break;
        }
    }
    
    
    $nav = $_REQUEST['nav'];
     
    if ( !strcmp( $nav, "Next" ) )
    {
        if ( $step_num < $num_steps - 1 )
        {
            $step_num++;
            $_SESSION['sl_cur_step_num'] = $step_num;
            header( "Location: ".( $sequence[$step_num] ).".php" );
        }
    }
    else if ( !strcmp( $nav, "Back" ) )
    {
        if ( $step_num > 0 )
        {
            $step_num--;
            $_SESSION['sl_cur_step_num'] = $step_num;
            header( "Location: ".( $sequence[$step_num] ).".php" );
        }
        else if ( $step_num == 0 )
        {
            header( "Location: dbms_type.php" );
        }
    }
    else if ( !strcmp( $nav, "Install" ) )
    {
        header( "Location: install.php" );
    }
?>
