<?php
    require_once( "../sl_root.php" );
    require_once( "installer/config_check.php" );
    require_once( "core/SLConfiguration.php" );
    require_once( "core/platform/platform_require.php" );
    
    session_start();
    
    require_once( "core/platform/platform_init.php" );

    $rdbms_install = array( "database_config", "locations", "admin_user", "authentication" );
    $sqlite_install = array( "locations", "admin_user", "authentication" ); 
    
    if ( !isset( $_SESSION['NEW_CONFIG'] ) )
    {
        $config = new SLConfiguration();

        if ( isset( $_SERVER['SERVER_NAME'] ) )
        {
            $config->setWebServerRoot( "http://".$_SERVER['SERVER_NAME'] );
        }
        else
        {
            $config->setWebServerRoot( "http://www.yourdomain.com" );
        }

        if ( isset( $_SERVER['REQUEST_URI'] ) )
        {
            $uri = stripslashes( $_SERVER['REQUEST_URI'] );
            $index = strpos( $uri, "installer/installer.php" );
            $root = substr( $uri, 0, $index  );
            $config->setMediaServerRoot( $root );
        }
        else
        {
            $config->setMediaServerRoot( "/streamline/" );
        }

        
        // Set Up Defaults
        $config->setTheme( "default" );
        
        if ( $sl_platform->getName() == 'Windows') 
        {
            $config->setMediaRoot( "C:\\media\\" );
        }
        else
        {
            $config->setMediaRoot( "/var/media/" );
        }
        
        $config->setServerTitle( "Streamline Media Server" );
        $config->setBrowserColumns( array( "title", "album", "artist" ) );
        $config->setStreamFormat( "%t - %n" );
        $config->setSortOrder( array( "TRACK", "TITLE" ) );
        $config->setBrowsingRequiresAuth( true );
        $config->setStreamingRequiresAuth( true );
        $config->setDownloadingRequiresAuth( true );
        $config->setAdminRequiresAuth( true );
        $config->setGlobalHACEnabled( false );
        $config->setBrowseHACEnabled( false );
        $config->setStreamHACEnabled( false );
        $config->setDownloadHACEnabled( false );
        
        $config->setBrowseAACEnabled( false );
        $config->setStreamAACEnabled( false );
        $config->setDownloadAACEnabled( false );

        $config->setLogBrowsing( true );
        $config->setLogStreaming( true );
        $config->setLogDownloading( true );
                
        $_SESSION['sl_install_db_type'] = "mysql";
        $_SESSION['sl_install_db_host'] = "localhost";
        $_SESSION['sl_install_db_user'] = "streamline";
        $_SESSION['sl_install_db_pass'] = "password";
        $_SESSION['sl_install_db_name'] = "streamline";
    }
    else
    {
        $config = $_SESSION['NEW_CONFIG'];
    }
    
   
    if ( !isset( $_SESSION['dbms_type'] ) )
    {
        header( "Location: install_type.php" );
        echo "\n";
        die();
    }
   
    switch ($_SESSION['dbms_type'])
    {
        case "rdbms":
            $sequence = $rdbms_install;
             break;

        case "sqlite":
            $sequence = $sqlite_install;
            break;

        default:
            header( "Location: install_type.php" );
            echo "\n";
            die();
            break;
    }
    
    $num_steps = count( $sequence );
    $_SESSION['sl_num_steps'] = $num_steps;
    
    if ( !isset( $_REQUEST['step'] ) )
    {
        $step = 1;
    }
    else
    {
        $step = intval( $_REQUEST['step'] );
    }

    $submit = $_REQUEST['submit'];
    
    $last_step = $step - 1;
    if ( $last_step >= 0 && $last_step < count( $sequence ) )
    {
        switch ( $sequence[$last_step] )
        {
            
            case "database_config":
                $_SESSION['sl_install_db_type'] = $_REQUEST['db_type'];
                $_SESSION['sl_install_db_host'] = $_REQUEST['db_host'];
                $_SESSION['sl_install_db_user'] = $_REQUEST['db_user'];
                $_SESSION['sl_install_db_pass'] = $_REQUEST['db_pass'];
                $_SESSION['sl_install_db_name'] = $_REQUEST['db_name'];
                break;
            
            case "locations":
                $config->setWebServerRoot( $_REQUEST['WebServerRoot'] );
                $config->setMediaServerRoot( $_REQUEST['MediaServerRoot'] );
                $config->setMediaRoot( $sl_platform->normalizePath( $_REQUEST['MediaRoot'] ) );
                break;

            case "presentation":
                $config->setBrowseFormat( $_REQUEST['BrowseFormat'] );
                $config->setStreamFormat( $_REQUEST['StreamFormat'] );
                $config->setSortOrder( $_REQUEST['SortOrder'] );
                $config->setTheme( $_REQUEST['Theme'] );
                break;

            case "admin_user":
                $_SESSION['SL_ADMIN_USER'] = stripslashes( $_REQUEST['admin_user'] );
                $_SESSION['SL_ADMIN_FNAME'] = stripslashes( $_REQUEST['admin_fname'] );
                $_SESSION['SL_ADMIN_LNAME'] = stripslashes( $_REQUEST['admin_lname'] );
                $_SESSION['SL_ADMIN_EMAIL'] = stripslashes( $_REQUEST['admin_email'] );
                $_SESSION['SL_ADMIN_PASS'] = stripslashes( $_REQUEST['admin_pass'] );
                break;

            case "authentication":
                $config->setBrowsingRequiresAuth( (strtoupper( $_REQUEST['ProtectBrowsing'] ) == "YES")?true:false );
                $config->setStreamingRequiresAuth( (strtoupper( $_REQUEST['ProtectStreaming'] ) == "YES")?true:false );
                $config->setDownloadingRequiresAuth( (strtoupper( $_REQUEST['ProtectDownloading'] ) == "YES")?true:false );
                break;

            default:
                break;
        }
    }
    
     
    $_SESSION['NEW_CONFIG'] = $config;
    
    if ( !strcmp( $submit, "Next" ) )
    {
        if ( $step < $num_steps )
        {
            $_SESSION['curstep'] = $step + 1;
            header( "Location: ".( $sequence[$step] ).".php" );
        }
        else
        { 
            header( "Location: confirm.php" );
        }
    }
    else if ( !strcmp( $submit, "Back" ) )
    {
        if ( $step > 1 )
        {
            $_SESSION['curstep'] = $step - 1;
            header( "Location: ".( $sequence[$step - 2] ).".php" );
        }
        else if ( $step == -1 )
        {
            $_SESSION['curstep'] = $num_steps;
            header( "Location: ".( $sequence[$num_steps - 1] ).".php" );
        }
    }
    else if ( !strcmp( $submit, "Install" ) )
    {
        header( "Location: install.php" );
    }
?>
