<?
    require_once( "../sl_root.php" );
    require_once( "core/streamline_init.php" );
    require_once( "core/streamline_functions.php" );
    require_once( "core/MediaStreamer.php" );
    require_once( "core/db/db_init.php" );
    require_once( "core/stats/SLDailyStatsEngine.php" );
    require_once( "core/stats/SLMediaStatsEngine.php" );
    require_once( "core/stats/SLUserStatsEngine.php" );
    
    // First Check to see if we require login for streaming. 
    if ( $sl_access_controler->requireLoginForStreaming() )
    {
        require_once( "core/auth/http_login.php" );
    }

    // Now see if access to streaming is allowed.
    if ( !$sl_access_controler->getStreamAccess() )
    {
        header('HTTP/1.1 403\r\n');
        echo "\n";
        die();
    }
    

    if ( isset( $_SESSION[SL_AUTH_USER] ) )
    {
        $auth_user = $_SESSION[SL_AUTH_USER];
        
        require_once( "core/db/tables/SLUserTable.php" );
        $sl_user_table = new SLUserTable( $db );
        $sl_user = $sl_user_table->getUserById( $auth_user->getUID() );
        $_user_name = $sl_user->getUserName();
        
        $user_stats_engine = &new SLUserStatsEngine( $db );
        $user_stats_engine->logStream( $sl_user->getUserId() );
    }
    else
    {
        $_user_name = "Unknown";
    }
 
     
    $stream_root = joinURLPath( $sl_config->getMediaServerRoot(), "stream" );
    $media_root = $sl_config->getMediaRoot();
    
    if ( $sl_config->getMaskURLs() )
    {
        $uri = stripslashes( $sl_web_server->getRequestURI() );
        $req_path = urldecode( $uri );
        $len = strlen( $req_path );
        $rootlen = strlen( $stream_root );
        $index = strpos( $req_path, $stream_root );
        $rel_path = substr( $req_path, $index + $rootlen, $len - ($index + $rootlen) );
    }
    else
    {
        $loc = stripslashes( urldecode( isset( $_REQUEST['media'] )?$_REQUEST['media']:"/" ) );
        $rel_path = $loc;
    }
    
    $media_path = joinFilePath( $media_root, $rel_path );
    $file_size = filesize( $media_path );

    // Check to make sure the file exists.

    if ( !@is_file( $media_path ) || !@is_readable( $media_path ) )
    {
        header('HTTP/1.1 404\r\n');
        echo "\n";
        exit();
    }
    
    $range = $sl_web_server->getHTTPRequestHeader( "Range" );
    if ( !is_null( $range ) )
    {
        // The range field should look something like this:
        //      bytes=7483940-.  
        // It will always start with bytes=.  We don't care about that so
        // We chop that off.  The trailing - just means from that point on.
        // we don't need that either.
        $range_len = strlen( $range );
        $pre_len = 6;
        $range = substr( $range, $pre_len, ( $range_len - $pre_len ) - 1 );
    }
    else
    {
        $range = 0;
    }
    
    $sl_logger->logStreamRequest( $rel_path, $_user_name );
    $daily_stats_engine = &new SLDailyStatsEngine( $db );
    $daily_stats_engine->logStream();
    $media_stats_engine = &new SLMediaStatsEngine( $db );
    $media_stats_engine->logStream( $rel_path );

    $tag = $sl_media_info_cache->getMediaInfo( $rel_path );
    $temp = explode( "/", $rel_path );
    $filename = array_pop( $temp );
    if ( $filename == "" )
    {
        $filename = array_pop( $temp );
    }
    
    $title = formatID3String( $tag, $sl_config->getStreamFormat(), $filename );
    $streamer = new MediaStreamer( $media_path, $range, $title, $tag->getMimeType() );
    $streamer->sendHeaders();
    $result = $streamer->streamMedia();
    
    if ( !$result )
    {
        $sl_logger->logError( "Could not stream file: \"$media_path\"", $_user_name);
    }
?>
